Enum rustc_ap_rustc_feature::UnstableFeatures [−][src]
pub enum UnstableFeatures {
Disallow,
Allow,
Cheat,
}Variants
Hard errors for unstable features are active, as on beta/stable channels.
Allow features to be activated, as on nightly.
Errors are bypassed for bootstrapping. This is required any time during the build that feature-related lints are set to warn or above because the build turns on warnings-as-errors and uses lots of unstable features. As a result, this is always required for building Rust itself.
Implementations
This takes into account RUSTC_BOOTSTRAP.
If krate is Some, then setting RUSTC_BOOTSTRAP=krate will enable the nightly features.
Otherwise, only RUSTC_BOOTSTRAP=1 will work.